Converts a `LatentNeuroVec` to a standard R 4D array by reconstructing the full data from the latent representation.
Usage
# S3 method for class 'LatentNeuroVec'
as.array(x, ...)Converts a `LatentNeuroVec` to a standard R 4D array by reconstructing the full data from the latent representation.
# S3 method for class 'LatentNeuroVec'
as.array(x, ...)