Skip to contents

Apply a summary function to voxel data within each cluster

Usage

summarize_by_clusters(nvec, clusters, fun = mean)

Arguments

nvec

A NeuroVec object containing the voxel data

clusters

A ClusteredNeuroVol object defining the clusters

fun

The summary function to apply (default: mean)

Value

A matrix with clusters as rows and time points as columns