Write, append, and open row-sharded HDF5 frames
Source:R/frame_shards_h5.R
write_sharded_frame_h5.RdA sharded frame is a directory containing immutable FDS v1 HDF5 frame files and one small root manifest. Appending writes a new shard and then atomically replaces only the root manifest; previously committed HDF5 files are never opened for writing or rewritten.
Usage
write_sharded_frame_h5(
x,
path,
shard_id = "shard-000001",
chunk_dims = NULL,
layout = c("balanced", "imagewise", "featurewise"),
target_chunk_bytes = getOption("fmristore.target_chunk_bytes", 1024^2),
memory_budget = getOption("fmridataset.block_budget", 512 * 1024^2)
)
append_frame_shard_h5(
x,
path,
shard_id,
chunk_dims = NULL,
layout = c("balanced", "imagewise", "featurewise"),
target_chunk_bytes = getOption("fmristore.target_chunk_bytes", 1024^2),
memory_budget = getOption("fmridataset.block_budget", 512 * 1024^2)
)
frame_shard_manifest(path)
open_sharded_frame_h5(path)